@@ -39,15 +39,21 @@ class TableOriginRxnPatent:
     @classmethod
     def _reset_rxn(cls, rxn):
         rxn['source'] = json.loads(rxn['source'].replace('""', '"')[1:-1])
-        rxn['reactants'] = json.loads(rxn['reactants'].replace('""', '"')[1:-1])
-        rxn['products'] = json.loads(rxn['products'].replace('""', '"')[1:-1])
-        rxn['spectators'] = json.loads(rxn['spectators'].replace('""', '"')[1:-1])
-        rxn['actions'] = json.loads(rxn['actions'].replace('""', '"')[1:-1])
+        cls._reset_rxn_with_key(rxn, 'reactants')
+        cls._reset_rxn_with_key(rxn, 'products')
+        cls._reset_rxn_with_key(rxn, 'spectators')
+        cls._reset_rxn_with_key(rxn, 'actions')
         return rxn
 
+    @classmethod
+    def _reset_rxn_with_key(cls, rxn, key):
+        if rxn[key] != '[]':
+            rxn[key] = json.loads(rxn[key].replace('""', '"')[1:-1])
+        else:
+            rxn[key] = []
+
 
 if __name__ == "__main__":
     dbb = DBBase('114.214.205.122', 1684, 'rxndb', 'postgres', '65zm]+7[d1Kb')
     torp = TableOriginRxnPatent(dbb)
-    for r in torp.get_all_rxns():
-        print(r['rid'])
+    print(torp.get_rxn_by_rid(3))
